summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorjhb <jhb@FreeBSD.org>2001-01-24 14:28:24 +0000
committerjhb <jhb@FreeBSD.org>2001-01-24 14:28:24 +0000
commitfbc5ce7842c2c2dff2f5817488e067de84055548 (patch)
tree31939639264a186d38c440d1049a9edc1eda167c
parent15b24a1b98e41034b25007ab5b476123ce37199f (diff)
downloadFreeBSD-src-fbc5ce7842c2c2dff2f5817488e067de84055548.zip
FreeBSD-src-fbc5ce7842c2c2dff2f5817488e067de84055548.tar.gz
Catch up to proc flag changes.
-rw-r--r--usr.bin/w/proc_compare.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/usr.bin/w/proc_compare.c b/usr.bin/w/proc_compare.c
index a94a6b2..6517dee 100644
--- a/usr.bin/w/proc_compare.c
+++ b/usr.bin/w/proc_compare.c
@@ -55,7 +55,7 @@ static const char rcsid[] =
* with the highest cpu utilization is picked (p_estcpu). Ties are
* broken by picking the highest pid.
* 3) The sleeper with the shortest sleep time is next. With ties,
* we pick out just "short-term" sleepers (P_SINTR == 0).
* 4) Further ties are broken by picking the highest pid.
*
* If you change this, be sure to consider making the change in the kernel
@@ -116,9 +116,9 @@ proc_compare(p1, p2)
/*
* favor one sleeping in a non-interruptible sleep
*/
- if (p1->ki_flag & P_SINTR && (p2->ki_flag & P_SINTR) == 0)
+ if (p1->ki_sflag & PS_SINTR && (p2->ki_sflag & PS_SINTR) == 0)
return (1);
- if (p2->ki_flag & P_SINTR && (p1->ki_flag & P_SINTR) == 0)
+ if (p2->ki_sflag & PS_SINTR && (p1->ki_sflag & PS_SINTR) == 0)
return (0);
return (p2->ki_pid > p1->ki_pid); /* tie - return highest pid */
}
@@ -55,7 +55,7 @@ static const char rcsid[] =
* broken by picking the highest pid.
* 3) The sleeper with the shortest sleep time is next. With ties,
- * we pick out just "short-term" sleepers (P_SINTR == 0).
+ * we pick out just "short-term" sleepers (PS_SINTR == 0).
* 4) Further ties are broken by picking the highest pid.
*
OpenPOWER on IntegriCloud